Index: sdk/lib/io/process.dart |
diff --git a/sdk/lib/io/process.dart b/sdk/lib/io/process.dart |
index 0f89a300af56c2503fb669358c259f0b19f91cd3..5ca1597656995076dedcdf240ea722906b657edf 100644 |
--- a/sdk/lib/io/process.dart |
+++ b/sdk/lib/io/process.dart |
@@ -129,7 +129,7 @@ abstract class Process { |
* |
* The encoding used for decoding `stdout` and `stderr` into text is |
* controlled through [stdoutEncoding] and [stderrEncoding]. The |
* default encoding is `Encoding.SYSTEM`. If `null` is used no |
* decoding will happen and the [ProcessResult] will hold binary |
* data. |
* |
@@ -144,8 +144,8 @@ abstract class Process { |
Map<String, String> environment, |
bool includeParentEnvironment: true, |
bool runInShell: false, |
- Encoding stdoutEncoding: Encoding.SYSTEM, |
- Encoding stderrEncoding: Encoding.SYSTEM}); |
+ Encoding stdoutEncoding: SYSTEM_ENCODING, |
+ Encoding stderrEncoding: SYSTEM_ENCODING}); |
/** |
@@ -164,8 +164,8 @@ abstract class Process { |
Map<String, String> environment, |
bool includeParentEnvironment: true, |
bool runInShell: false, |
- Encoding stdoutEncoding: Encoding.SYSTEM, |
- Encoding stderrEncoding: Encoding.SYSTEM}); |
+ Encoding stdoutEncoding: SYSTEM_ENCODING, |
+ Encoding stderrEncoding: SYSTEM_ENCODING}); |
/** |
* Returns the standard output stream of the process as a [:Stream:]. |
@@ -129,7 +129,7 @@ abstract class Process { |
* The encoding used for decoding `stdout` and `stderr` into text is |
* controlled through [stdoutEncoding] and [stderrEncoding]. The |
- * default encoding is `Encoding.SYSTEM`. If `null` is used no |
+ * default encoding is [SYSTEM_ENCODING]. If `null` is used no |
* decoding will happen and the [ProcessResult] will hold binary |
* data. |